@@ -1,4 +1,7 @@
-use serde::Deserialize;
+use {
+    crate::*,
+    serde::Deserialize,
+};
 
 /// One of the possible job that bacon can run
 #[derive(Debug, Clone, Deserialize)]
@@ -19,4 +22,9 @@ pub struct Job {
     /// always captured)
     #[serde(default)]
     pub need_stdout: bool,
+
+    /// the optional action to run when there's no
+    /// error, warning or test failures
+    #[serde(default)]
+    pub on_success: Option<Action>,
 }
