@@ -1,107 +1,43 @@
 use {
     crate::*,
-    anyhow::*,
-    cargo_metadata::MetadataCommand,
+    anyhow::Result,
     notify::{RecommendedWatcher, RecursiveMode, Watcher},
     std::{
         collections::HashSet,
-        env,
-        fs,
         iter,
         path::PathBuf,
         process::Command,
     },
 };
 
-pub struct MissionLocation {
-    pub intended_dir: PathBuf,
-    pub package_directory: PathBuf,
-    pub cargo_toml_file: PathBuf,
-    pub intended_is_package: bool,
-}
-
-impl MissionLocation {
-    pub fn new(args: &Args) -> Result<Self> {
-        let intended_dir = args
-            .path
-            .as_ref()
-            .map_or_else(|| env::current_dir().unwrap(), PathBuf::from);
-        let intended_dir: PathBuf = fs::canonicalize(&intended_dir)?;
-        let mut package_directory = intended_dir.clone();
-        let mut intended_is_package = true;
-        let cargo_toml_file = loop {
-            let cargo_toml_file = package_directory.join("Cargo.toml");
-            if cargo_toml_file.exists() {
-                break cargo_toml_file;
-            }
-            intended_is_package = false;
-            package_directory = match package_directory.parent() {
-                Some(dir) => dir.to_path_buf(),
-                None => {
-                    bail!(
-                        "Cargo.toml file not found.\n\
-                        bacon must be launched \n\
-                        * in a rust project directory\n\
-                        * or with a rust project directory given in argument\n\
-                        (a rust project directory contains a Cargo.toml file or has such parent)\n\
-                        "
-                    );
-                }
-            };
-        };
-        Ok(Self {
-            intended_dir,
-            package_directory,
-            cargo_toml_file,
-            intended_is_package,
-        })
-    }
-    pub fn package_name(&self) -> String {
-        self.package_directory
-            .file_name()
-            .unwrap()
-            .to_string_lossy()
-            .to_string()
-    }
-    pub fn package_config_path(&self) -> PathBuf {
-        self.package_directory.join("bacon.toml")
-    }
-}
-
 /// the description of the mission of bacon
 /// after analysis of the args, env, and surroundings
 #[derive(Debug)]
-pub struct Mission {
-    pub package_name: String,
+pub struct Mission<'s> {
+    pub location_name: String,
     pub job_name: String,
     cargo_execution_directory: PathBuf,
     job: Job,
     files_to_watch: Vec<PathBuf>,
     directories_to_watch: Vec<PathBuf>,
-    pub settings: Settings,
+    pub settings: &'s Settings,
 }
 
-impl Mission {
+impl<'s> Mission<'s> {
     pub fn new(
-        location: MissionLocation,
-        package_config: &PackageConfig,
-        job_name: Option<&str>,
-        settings: Settings,
+        location: &MissionLocation,
+        job_name: String,
+        job: Job,
+        settings: &'s Settings,
     ) -> Result<Self> {
-        let package_name = location.package_name();
+        let location_name = location.name();
         let add_all_src = location.intended_is_package;
-        let (job_name, job) = package_config
-            .get_job(job_name)
-            .map(|(n, j)| (n.to_string(), j.clone()))?;
-        let metadata = MetadataCommand::new()
-            .manifest_path(&location.cargo_toml_file)
-            .exec()?;
         let mut files_to_watch: Vec<PathBuf> = Vec::new();
         let mut directories_to_watch = Vec::new();
         if !location.intended_is_package {
-            directories_to_watch.push(location.intended_dir);
+            directories_to_watch.push(location.intended_dir.clone());
         }
-        for item in metadata.packages {
+        for item in &location.packages {
             if item.source.is_none() {
                 let item_path = item
                     .manifest_path
@@ -120,16 +56,16 @@ impl Mission {
                     }
                 }
                 if item.manifest_path.exists() {
-                    files_to_watch.push(item.manifest_path.into());
+                    files_to_watch.push(item.manifest_path.clone().into());
                 } else {
                     warn!("missing manifest file: {:?}", item.manifest_path);
                 }
             }
         }
 
-        let cargo_execution_directory = location.package_directory;
+        let cargo_execution_directory = location.package_directory.clone();
         Ok(Mission {
-            package_name,
+            location_name,
             job_name,
             cargo_execution_directory,
             job,
@@ -139,6 +75,11 @@ impl Mission {
         })
     }
 
+    /// the action bound to success on this job
+    pub fn on_success(&self) -> &Option<Action> {
+        &self.job.on_success
+    }
+
     /// configure the watcher with files and directories to watch
     pub fn add_watchs(&self, watcher: &mut RecommendedWatcher) -> Result<()> {
         for file in &self.files_to_watch {
@@ -161,6 +102,7 @@ impl Mission {
         let mut no_default_features_done = false;
         let mut features_done = false;
         let mut last_is_features = false;
+        let tokens = tokens.chain(&self.settings.additional_job_args);
         for arg in tokens {
             if last_is_features {
                 if self.settings.all_features {
